summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichael Larson <slioch@eng-140.vyatta.com>2008-03-20 10:21:01 -0700
committerMichael Larson <slioch@eng-140.vyatta.com>2008-03-20 10:21:01 -0700
commit83ed3b6af4bc060409d1143ba4509eb0f00799c1 (patch)
tree97b66d3f9a637693e264e7ff0f0d5273a4fd35f8
parent60a813c52d876cb99d444510d8fc8598d97aa268 (diff)
downloadquagga-83ed3b6af4bc060409d1143ba4509eb0f00799c1.tar.bz2
quagga-83ed3b6af4bc060409d1143ba4509eb0f00799c1.tar.xz
bumped up netlink recv buffer limits for zebra--should alleviate netlink error msgs that occur under large routing tables when layer
2 event occurs.
-rw-r--r--debian/vyatta-quagga.init.d2
-rw-r--r--zebra/rt_netlink.c4
2 files changed, 3 insertions, 3 deletions
diff --git a/debian/vyatta-quagga.init.d b/debian/vyatta-quagga.init.d
index 20c23671..0bf2eaab 100644
--- a/debian/vyatta-quagga.init.d
+++ b/debian/vyatta-quagga.init.d
@@ -33,7 +33,7 @@ done
declare -a common_args=( -d -P 0 )
declare -a watchlink_args=( -s -d -i $pid_dir/watchlink.pid )
-declare -a zebra_args=( ${common_args[@]} -l -s 223232 -i $pid_dir/zebra.pid )
+declare -a zebra_args=( ${common_args[@]} -l -s 1048576 -i $pid_dir/zebra.pid )
declare -a ripd_args=( ${common_args[@]} -i $pid_dir/ripd.pid )
declare -a ripngd_args=( ${common_args[@]} -i $pid_dir/ripngd.pid )
declare -a ospfd_args=( ${common_args[@]} -i $pid_dir/ospfd.pid )
diff --git a/zebra/rt_netlink.c b/zebra/rt_netlink.c
index ea8aeb1d..f071eb24 100644
--- a/zebra/rt_netlink.c
+++ b/zebra/rt_netlink.c
@@ -328,8 +328,8 @@ netlink_parse_info (int (*filter) (struct sockaddr_nl *, struct nlmsghdr *),
while (1)
{
- //increased from 4096 to 8192 as recvmsg overrun error
- char buf[8192];
+ //increased from 4096 to 32768 as recvmsg overrun error
+ char buf[32768];
struct iovec iov = { buf, sizeof buf };
struct sockaddr_nl snl;
struct msghdr msg = { (void *) &snl, sizeof snl, &iov, 1, NULL, 0, 0 };